@@ -1,13 +1,26 @@
+"""
+performance comparison with huge number of elements
+"""
+
 from __future__ import absolute_import
 
 import timeit
 import os
 import tempfile
+import sys
 
 
-max_items = 5000
+
+#max_items = 5000
 max_items = 500000
 
+itree_only=False
+if len(sys.argv)==2:
+    max_items=int(sys.argv[1])
+if len(sys.argv)==3:
+    max_items=int(sys.argv[1])
+    itree_only=int(sys.argv[2])
+
 repeat = 4
 
 
@@ -64,6 +77,15 @@ def performance_it_get_tags():
     for i in range(max_items):
         a = dt['%i' % i]
 
+def performance_it_get_tags():
+    #tag access
+    global dt_root,max_items
+    dt=dt_root
+
+    #read itertree items per tag and index
+    for i in range(max_items):
+        a = dt['%i' % i]
+
 def performance_it_get_tag_idx():
     #tag access
     global dt_root,max_items
@@ -131,6 +153,8 @@ print('Exectime time itertree load from file: {}'.format(a / repeat))
 
 print('Loaded iTree is equal: %s'%(str(dt_root.equal(load_root))))
 
+if itree_only:
+    exit(0)
 
 try:
     from lldict4 import llDict as llDict2
